@@ -1,7 +1,7 @@
 #' Normalize numeric variable to 0-1 range
 #'
 #' Performs a normalization of data, i.e., it scales variables in the range
-#' 0 - 1. This is a special case of [data_rescale()]. `unnormalize()` is the
+#' 0 - 1. This is a special case of [rescale()]. `unnormalize()` is the
 #' counterpart, but only works for variables that have been normalized with
 #' `normalize()`.
 #'
@@ -52,20 +52,26 @@ normalize <- function(x, ...) {
 #' @rdname normalize
 #' @export
 normalize.numeric <- function(x, include_bounds = TRUE, verbose = TRUE, ...) {
-
-  # Warning if all NaNs
-  if (all(is.na(x))) {
+  # Warning if all NaNs or infinite
+  if (all(is.infinite(x) | is.na(x))) {
     return(x)
   }
 
+  # safe name, for later use
+  if (is.null(names(x))) {
+    name <- deparse(substitute(x))
+  } else {
+    name <- names(x)
+  }
+
+  # Get infinite and replace by NA (so that the normalization doesn't fail)
+  infinite_idx <- is.infinite(x)
+  infinite_vals <- x[infinite_idx]
+  x[infinite_idx] <- NA
+
 
   # Warning if only one value
-  if (length(unique(x)) == 1) {
-    if (is.null(names(x))) {
-      name <- deparse(substitute(x))
-    } else {
-      name <- names(x)
-    }
+  if (insight::n_unique(x) == 1) {
     if (verbose) {
       warning(insight::format_message(paste0("Variable `", name, "` contains only one unique value and will not be normalized.")), call. = FALSE)
     }
@@ -74,12 +80,7 @@ normalize.numeric <- function(x, include_bounds = TRUE, verbose = TRUE, ...) {
 
 
   # Warning if logical vector
-  if (length(unique(x)) == 2) {
-    if (is.null(names(x))) {
-      name <- deparse(substitute(x))
-    } else {
-      name <- names(x)
-    }
+  if (insight::n_unique(x) == 2) {
     if (verbose) {
       warning(insight::format_message(paste0("Variable `", name, "` contains only two different values. Consider converting it to a factor.")), call. = FALSE)
     }
@@ -92,6 +93,9 @@ normalize.numeric <- function(x, include_bounds = TRUE, verbose = TRUE, ...) {
     out <- (out * (length(out) - 1) + 0.5) / length(out)
   }
 
+  # Re-insert infinite values
+  out[infinite_idx] <- infinite_vals
+
   attr(out, "include_bounds") <- isTRUE(include_bounds)
   attr(out, "min_value") <- min(x, na.rm = TRUE)
   attr(out, "range_difference") <- diff(range(x, na.rm = TRUE))
@@ -166,7 +170,6 @@ normalize.data.frame <- function(x,
                                  ignore_case = FALSE,
                                  verbose = TRUE,
                                  ...) {
-
   # evaluate select/exclude, may be select-helpers
   select <- .select_nse(select, x, exclude, ignore_case, verbose = verbose)
   x[select] <- lapply(x[select], normalize, include_bounds = include_bounds, verbose = verbose)
