@@ -165,7 +165,7 @@ test_that("unstandardize, numeric", {
   expect_equal(rez, iris$Petal.Length, tolerance = 1e-3, ignore_attr = TRUE)
 })
 
-test_that("unstandardize, dataframe", {
+test_that("unstandardize, data frame", {
   skip_if_not_installed("poorman")
 
   data(iris)
@@ -216,3 +216,24 @@ test_that("un/standardize, matrix", {
   expect_equal(unstandardize(z1), x)
   expect_equal(unstandardize(z2), unstandardize(z1))
 })
+
+test_that("unstandardize with reference (data frame)", {
+  x <- standardize(x = iris, reference = iris)
+  x2 <- unstandardize(x, reference = iris)
+  expect_equal(x2, iris, ignore_attr = TRUE)
+
+  x <- standardize(x = iris, reference = iris, robust = TRUE)
+  x2 <- unstandardize(x, reference = iris, robust = TRUE)
+  expect_equal(x2, iris, ignore_attr = TRUE)
+})
+
+test_that("unstandardize does nothing with characters and factors", {
+  expect_equal(
+    unstandardise(c("a", "b")),
+    c("a", "b")
+  )
+  expect_equal(
+    unstandardise(factor(c(1, 2))),
+    factor(c(1, 2))
+  )
+})
